@@ -3,8 +3,8 @@
 #' Allows whitespace before and after the description
 #' @keywords internal
 #' @noRd
-step_regex <- function(step_name, description) {
-  paste0("^\\s*", step_name, " ", description, "\\s*$")
+step_regex <- function(description) {
+  paste0("^\\s*", description, "\\s*$")
 }
 
 #' @keywords internal
@@ -18,8 +18,8 @@ make_step <- function(prefix) {
     assert_subset("context", names(args[length(args)]))
     step <- structure(
       implementation,
-      description = paste(prefix, description),
-      detect = step_regex(prefix, description),
+      description = description,
+      detect = step_regex(description),
       class = c("step", class(implementation))
     )
     register_step(step)
@@ -34,23 +34,57 @@ make_step <- function(prefix) {
 #' @name step
 #' @param description A description of the step.
 #'
-#' A simple version of a \href{https://github.com/cucumber/cucumber-expressions}{Cucumber expression}.
-#' The description is used by the \code{cucumber::test} function to find an implementation of a step
-#' from a feature file.
-#' The description can contain placeholders in curly braces, e.g. \code{"I have {int} cucumbers in my basket"}.
-#' If no step definition is found an error will be thrown. If multiple steps definitions for a single step
-#' are found an error will be thrown. Make sure the description is unique for each step.
+#' Cucumber executes each step in a scenario one at a time, in the sequence you’ve written them in.
+#' When Cucumber tries to execute a step, it looks for a matching step definition to execute.
 #'
-#' @param implementation A function that will be run when the step is executed.
-#' The implementation function should always have the last parameter named \code{context}.
-#' It holds the environment where state should be stored to be passed to the next step.
+#' **Keywords are not taken into account when looking for a step definition.**
+#' This means you cannot have a `Given`, `When`, `Then`, `And` or `But` step with the same text as another step.
 #'
-#' If a step has a description \code{"I have {int} cucumbers in my basket"} then the implementation
-#' function should be a \code{function(n_cucumbers, context)}. The \code{{int}} value will be passed to
-#' \code{n_cucumbers}, this parameter can have any name.
+#' Cucumber considers the following steps duplicates:
+#'
+#' ```
+#' Given there is money in my account
+#' Then there is money in my account
+#' ```
+#'
+#' This might seem like a limitation, but it forces you to come up with a less ambiguous, more clear domain language:
+#'
+#' ```
+#' Given my account has a balance of £430
+#' Then my account should have a balance of £430
+#' ```
+#'
+#' To pass arguments, description can contain placeholders in curly braces.
+#'
+#' To match:
+#'
+#' ```
+#' Given my account has a balance of £430
+#' ```
+#'
+#' use:
+#'
+#' ```
+#' given("my account has a balance of £{float}", function(balance, context) {
+#'
+#' })
+#' ```
+#'
+#' If no step definition is found an error will be thrown.
+#'
+#' If multiple steps definitions for a single step are found an error will be thrown.
+#'
+#' @param implementation A function that will be run during test execution.
+#'
+#' The implementation function must always have the last parameter named `context`.
+#' It holds the environment where test state can be stored to be passed to the next step.
+#'
+#' If a step has a description `"I have {int} cucumbers in my basket"` then the implementation
+#' function should be `function(n, context)`. The `{int}` value will be passed to
+#' `n`, this parameter can have any name.
 #'
 #' If a table or a docstring is defined for a step, it will be passed as an argument after plceholder parameters
-#' and before \code{context}. The function should be a \code{function(n_cucumbers, table, context)}.
+#' and before `context`. The function should be a `function(n, table, context)`.
 #' See
 #' \href{https://github.com/jakubsob/cucumber/blob/main/inst/examples/table/tests/testthat/steps/steps.R}{an example}
 #' on how to write implementation that uses tables or docstrings.
@@ -75,10 +109,11 @@ make_step <- function(prefix) {
 #'
 #' @details
 #' Placeholders in expressions are replaced with regular expressions that match values in the feature file.
-#' The regular expressions are generated during runtime based on defined parameter types.
-#' The expression \code{"I have {int} cucumbers in my basket"} will be converted to
-#' \code{"I have [+-]?(?<![.])[:digit:]+(?![.]) cucumbers in my basket"}. The extracted value of \code{{int}}
-#' will be passed to the implementation function after being transformed with \code{as.integer}.
+#' Regular expressions are generated during runtime based on defined parameter types.
+#'
+#' The expression `"I have {int} cucumbers in my basket"` will be converted to
+#' `"I have [+-]?(?<![.])[:digit:]+(?![.]) cucumbers in my basket"`. The extracted value of `{int}`
+#' will be passed to the implementation function after being transformed with `as.integer`.
 #'
 #' To define your own parameter types use \code{\link{define_parameter_type}}.
 #'
